#include <zephyr.h>
#include <drivers/flash.h>
#include <device.h>
#include <devicetree.h>
#include <stdio.h>
#include <string.h>
#include "stdlib.h"
#include <drivers/gpio.h>
#include <sys/util.h>
#include <sys/printk.h>
#include <inttypes.h>
#include <sys/reboot.h>
#include <storage/flash_map.h>
#include <fs/nvs.h>
#include "mcu_flash.h"


static struct nvs_fs fs;

#define STORAGE_NODE_LABEL storage


#define OTA_ID 8

static struct flash_pages_info info;
static const struct device *flash_dev;

void mcu_flash_init(void)
{
	flash_dev = FLASH_AREA_DEVICE(STORAGE_NODE_LABEL);
	if (!device_is_ready(flash_dev)) {
		printk("Flash device %s is not ready\n", flash_dev->name);
		return;
	}
	fs.offset = FLASH_AREA_OFFSET(storage);
	int rc = flash_get_page_info_by_offs(flash_dev, fs.offset, &info);
	if (rc) {
		printk("Unable to get page info\n");
		return;
	}
	fs.sector_size = info.size;
	fs.sector_count = 3U;

	rc = nvs_init(&fs, flash_dev->name);
	if (rc) {
		printk("Flash Init failed\n");
		return;
	}
}
void mcu_flash_uninit(void)
{
	
}

bool mcu_flash_need_ota()
{
	char buf[16]="";
	int rc = nvs_read(&fs, OTA_ID, &buf, sizeof(buf));
	if (rc > 0) {
		printk("read Id: %d, OTA tag: %s\n", OTA_ID, buf);
	}else
		printk("* not found OTA tag: %d (%d)\n", OTA_ID,rc);
	if(atol(buf)==1) return true;
	return 0;
}
void mcu_flash_write_ota(bool b)
{
	char buf[16]="0";
	if(b) strcpy(buf,"1");
	(void)nvs_write(&fs, OTA_ID, &buf, sizeof(buf));
	printk("write Id: %d, OTA tag: %s\n", OTA_ID, buf);
}

